This function performs Monte Carlo runs with random permutations of corpus tags in the graph provided and computes the heterocitation balance on the new graphs. Permutation is repeated over several iterations (set through the "rep" argument) and provides a baseline Dx values for the graph topology considered. This can then be compared with the Dx value obtained for the original graph to evaluate whether it could merely be the result of chance (see significance_Dx).
MC_baseline_distribution(gr, labels, infYearLimit, supYearLimit, rep = 20)Graph file (created with build_graph)
List of the names of the two corpora studied (e.g. c("Computer Science", "Mathematics")), present in the "Corpus" attribute
Minimum year considered in this study
Maximum year considered in this study
Number of Monte Carlo iterations
This function currently plots the histograms of distribution of Dx values generated through random permutations of corpus tags among the records. Returns a list containing:
Dx value for corpus 1 per iteration
Dx value for corpus 2 per iteration
Global Dx value per iteration