Learn R Programming

Diderot (version 0.13)

compute_citation_ranking: Function to compute the citation ranking.

Description

This function computes the citation count for each graph node (i.e. publication).

Usage

compute_citation_ranking(gr, labels, write_to_graph = F)

Arguments

gr

Citation graph

labels

Labels (i.e. names) of the two corpora featured in the graph.

write_to_graph

Flag to indicate whether to write results to the graph (i.e. save citation count values as node attributes).

Value

If write_to_graph is FALSE, returns a list of entries (authors, title, year, corpus, citations) sorted by decreasing citation count. Else, returns the graph given as input to which citation count values are added as node attributes.

See Also

compute_BC_ranking, compute_Ji_ranking

Examples

Run this code
# NOT RUN {
labels<-c("Corpus1","Corpus2")

# Build a bibliographical dataset from Scopus exports
db<-create_bibliography(corpora_files=c(tempfi1,tempfi2), 
                        labels=labels, keywords=NA)
# }
# NOT RUN {
# Build graph
gr<-build_graph(db=db,small.year.mismatch=TRUE, attrs=c("Corpus","Year","Authors"), nb.cores=1)

# Compute Citation Ranking
compute_citation_ranking(gr, labels)
# }

Run the code above in your browser using DataLab